function Design
%DESIGN Create time profiles with unequal observations per subject.
%   DESIGN produces a graph illustrating unbalanced and sparse drug
%   concentrations data for three individuals where the number of
%   observation per subject is unequal. The function is linked to
%   Fig. 6.1 (in the book).

close all; clc; clear;
ka = [1.5 0.5 1]; ke = [0.5 0.1 0.2]; V = [1 1 1]; 
time = (0:0.1:10)';
conc = @(t,V,ka,ke) 1/V*ka/(ka-ke)*(exp(-ke*t)-exp(-ka*t));
set(axes, 'FontSize', 15);
h = plot(time,conc(time,V(1),ka(1),ke(1)),'--r', ... 
         time,conc(time,V(2),ka(2),ke(2)),'--b', ... 
         time,conc(time,V(3),ka(3),ke(3)),'--k', 'LineWidth',0.5);
% Exclude line from legend
for hi = h'      % h' - transposed vector of pointers
    set(get(get(hi,'Annotation'),'LegendInformation'), ...
        'IconDisplayStyle','off'); 
end
hold on
s1t = 4;                                   
plot(s1t,conc(s1t,V(1),ka(1),ke(1)),'vr','MarkerSize',10,'MarkerFaceColor','r')
s2t = [0.5 4 9];       
plot(s2t,conc(s2t,V(2),ka(2),ke(2)),'sb','MarkerSize',10,'MarkerFaceColor','b')
s3t = [0.1 0.5 1 2 3 4 6 8];
plot(s3t,conc(s3t,V(3),ka(3),ke(3)),'ok','MarkerSize',10,'MarkerFaceColor','k')
legend('subject 1','subject 2','subject 3')
xlabel('Time'); ylabel('Drug concentration')
print('-dtiff','-r800','design')
end


