function DiseaseProgressionTreatmentLinear
%DISEASEPROGRESSIONTREATMENTLINEAR Linear disease progression with
%and without treatment
%   DISEASEPROGRESSIONTREATMENTLINEAR shows how disease-modifying
%   treatment changes the disease status trajectory in case of linear
%   disease progression. The function is linked to Fig. 5.39 (in the
%   book).


p.rin = 0.08;
p.k = 0.1;
p.rindrug = 10;
p.kdrug = 3;
p.emax = 4;
p.ec50 = 2;

p.rindrug =0;
p.symp = 0;
p.prot = 0;
[t, y] = ode45(@derivatives,[0 40],0,[],p);
set(axes,'FontSize', 15)
p1 = plot(t,y(:,1),'k', 'LineWidth',2);
hold on
axis([0 40 0.0 1])

p.rindrug =1;
p.symp = 1;
p.prot = 0;
[t, y] = ode45(@derivatives,[10 40],0,[],p);
plot(t,y(:,1),'b','LineWidth',2)
p3 = plot([10, 10],[0.2, 0],'-b','LineWidth',2);

p.symp = 0;
p.prot = 1;
p.rindrug = 1;
[t, y] = ode45(@derivatives,[10 40],0.2,[],p);
p4 = plot(t,y(:,1),'r','LineWidth',2);
xlabel('Time [arbitrary units]')
ylabel('Disease Status')
title('Linear Disease Progression') 

legend([p1,p3,p4],'Disease progression - no treatment', ...
    'Symptomatic treatment effect', ... 
    'Disease modifying treatment effect', 'Location', 'NorthWest')
print('-dtiff', '-r800', 'DiseaseProgressionTreatmentLinear')

end


function dydt = derivatives(t,~,p)
%DERIVATIVES Compute the right-hand side of the ODE.
%   DYDT = DERIVATIVES(T, Y, P) calculates |DYDT|, the right-hand
%   side of the ODE model, at points defined by the vector of
%   dependent variables |Y|, and time |T|, and with parameters |P|.

% disease  = y(1);
ddisease = 0.02- 0.015*(t>10&t<30)*p.prot - 0.03*(t>10 & t<10.1);  
dydt = ddisease;

end