% Parameter Estimation

setactiveconfigset(m1, cs);
% PK Data
pkData                     = PKData(dataToFit);
pkData.IndependentVarLabel = 'times';
pkData.DependentVarLabel   = {'conc_obs'};
% Define the parameters being estimated and their initial estimates.
estimatedParameters = {'ka', 'ke', 'V'};
initialEstimate     = [1.0, 0.2, 1.0];
% Build a model map.
pkModelMap            = PKModelMap;
pkModelMap.Observed   = {'unnamed.species_3'};
pkModelMap.Estimated  = estimatedParameters;
% Define estimate options.
options.ParamTransform = [0, 0, 0];
options.ErrorModel     = 'proportional';
options.Pooled         = false;
options.TolX           = 1.0E-8;
options.TolFun         = 1.0E-8;
options.MaxIter        = 100;
% Estimate parameter values.
[results, simdataI] = sbionlinfit(m1, pkModelMap, pkData, ... 
    initialEstimate, options);
ka  = results.ParameterEstimates.Estimate(1);
ke  = results.ParameterEstimates.Estimate(2);
V   = results.ParameterEstimates.Estimate(3);
cc  = 10*ka/(ke-ka)*(exp(-ka*data.time)-exp(-ke*data.time))/V;
ka1 = num2str(round(10*ka)/10);
ke1 = num2str(round(10*ke)/10);
V1  = num2str(round(10*V)/10);
% Configure the names of the resulting simulation data.
for i = 1:length(simdataI)
     simdataI(i).Name = 'SimData Individual';
end

% Convert dataToFit to a SimData object for plotting.
dataToFitPlot = SimData(dataToFit, 'times', '');
for i = 1:length(dataToFitPlot)
    dataToFitPlot(i).Name = 'Data To Fit';
end
set(axes, 'FontSize', 15)
plot(data.time,data.Data(:,3),'LineWidth',2)
hold on
plot(dataToFitPlot.time,dataToFitPlot.Data,'or','LineWidth',1.5)
plot(data.time,cc,'k','LineWidth',1.5)
xlabel('Time [h]');
ylabel('Value [units]')
legend('species_3: initial [ka=1.0, ke=0.2, V=1.0]', ... 
    'observations',['species_3: final [ka=',ka1,', ke=',ke1, ... 
    ', V=', V1,']'] );
print('-r800','-dtiff','estimation.tif')
