function PK1IV1d
%PK1IV1D Calculation of drug concentrations using Mass option.
%   PK1IV1D calculates drug concentrations for a one-compartment PK
%   model with IV input and first-order elimination. The procedure 
%   is based on an implicit ODE with the Mass option.

clear; clc; close all;
p.V = 5.0;     % L   
p.CL10 = 5.0;  % L/h
dose = 100;    % mg 
timeEnd = 10;  % h

options = odeset;
options.Mass = p.V;

[t, y] = ode15s(@derivalgeb, [0 timeEnd], dose/p.V, options, p);
c = y;
a = c*p.V;
plot(t,a,'-r',t,c,'b-','lineWidth',2)
legend('Drug amounts [mg]','Drug concentrations [mg/L]')
xlabel('Time [h]')
ylabel('Value')

end 	


function dydt = derivalgeb(~, y, p)
%DERIVALGEB Compute the right-hand side of the DAE.
%   DYDT = DERIVALGEB(T, Y, P) calculates |DYDT|, the right-hand
%   side of the DAE model at points defined by the vector of
%   dependent variables |Y|, time |T|, and with parameters |P|. 
%   The right-hand side represents both the differential equations 
%   and algebraic equations.

c1   = y(1);
dc1  = - p.CL10*c1; 
dydt = dc1;

end

