function PK1PO1() 
%PK1PO1 Solve one-compartment model with absorption and elimination
%   PK1PO1 calculates and produces graphs for the drug amount at
%   absorption site and drug concentration in one-compartment model
%   with first-order drug absorption and first-order elimination.

p.k01 = 0.5;    % 1/h
p.V = 1.0;      % L   
p.CL = 2.0;     % L/h
p.F = 1;        % L/h
dose = 100*p.F; % mg 

timeEnd = 12;
[t,y] = ode45(@derivatives, 0:0.01:timeEnd, [dose; 0], [], p);
[AX,H1,H2] = plotyy(t,y(:,1),t,y(:,2),'plot');
% Set colors for lines
set(H1,'LineWidth',2,'Color','blue')
set(H2,'LineWidth',2,'Color','red')
% Set colors for amount(t) 
set(get(AX(1),'Ylabel'),'String', ... 
    'Drug Amount at Site of Absorption','Color', 'blue', ... 
    'FontSize', 15) 
set(AX(1),'YColor', 'blue', 'FontSize', 15)
% Set colors for concentration(t)
set(get(AX(2),'Ylabel'),'String','Drug Concentrations','Color', ...
    'red', 'FontSize', 15) 
set(AX(2),'YColor', 'red', 'FontSize', 15)
title('One-Compartment - Oral Input')
xlabel('Time [h]')
legend('drug amount at site of absorption [mg]', ... 
        'drug concentrations [mg/L]')
print('-dtiff','-r900','PK1PO1.tif')

end     
 

function dydt = derivatives(~, y, p)
%DERIVATIVES Compute the right-hand side of the ODE.
%   DYDT = DERIVATIVES(T, Y, P) calculates |DYDT|, the right-hand
%   side of the ODE model, at points defined by the vector of
%   dependent variables |Y|, time |T|, and with parameters |P|.

dy1 = - p.k01*y(1);             
dy2 = p.k01*y(1) - p.CL/p.V*y(2);
dydt = [dy1; dy2];

end
