function bindingriccati()
%BINDINGRICCATI validate the analytical solution of Riccati equation
%   BINDINGRICCATI() compares two solutions of Riccati equation,
%   the analytical form to the numerical solution with ODE solver,   
%   and creates as output a graph with both solution. The presented  
%   type of equation is applied for building a mathematical models of
%   immunoradiometric assays. 

p.a = 2; 
p.b = 1; 
tspan = [0 1]; 
y0 = 0 ;                                 
[t,y] = ode45(@derivatives, tspan, y0, [], p); 
set(axes,'FontSize',15)
plot(t, y, 'xk','Markersize', 10 ); hold on   
y = fan(t,p);
plot(t, y, 'ok')
legend('numerical', 'analytical')
xlabel('t')
ylabel('y')
title('Solution of RICCATI Equation')
print('-r600', '-dtiff', 'riccatti')

end
 

function dydt = derivatives(~,y, p) 
%DERIVATIVES Compute the right-hand side of the ODE.
%   DYDT = DERIVATIVES(T, Y, P) calculates |DYDT|, the right-hand
%   side of the ODE model, at points defined by the vector of
%   dependent variables |Y|, and time |T|, and with parameters |P|.

dydt =y(1)^2-2*p.a*y(1)+p.b^2;

end 


function y = fan(t, p)
%FAN compute the analytical solution of Riccati equation
%   FAN(T,P) calculates values of Riccati solution at points |T|,
%   and given parameters in structure |P| 

s=-sqrt(p.a^2-p.b^2);
y = p.b^2./(p.a + s*coth(s*t));

end
