function consLegHan
%CONSLEGHAN Simulation of 2 cohorts and legend demonstration

ns = 10;
p = modelparams(ns); 
%cohort A
a0 = 100; c0 = 0; y0 = [a0; c0]; tspan = [0 15];
for id = 1:p.numSub 
    pind = struct('ka',p.ka(id), ... 
                  'V',p.V(id),   ...
                  'F',p.F(id),   ... 
                  'CL',p.CL(id));
    [t,y] = ode15s(@derivatives, tspan, y0, [], pind);
    hA = plot(t,y(:,2),'Color','b', 'LineWidth',2); hold on
    % AAA
end
%cohort B
a0 = 200; c0 = 0; y0 = [a0; c0]; tspan = [0 15];
for id = 1:p.numSub 
    pind = struct('ka',p.ka(id), ... 
                  'V',p.V(id),   ...
                  'F',p.F(id),   ... 
                  'CL',p.CL(id));
    [t,y] = ode15s(@derivatives, tspan, y0, [], pind);
    hB = plot(t,y(:,2),'Color','r','LineWidth',2 ); hold on
    % BBB
end

xlabel('Time'); ylabel('Concentration'); 

legend([hA hB],'cohort A','cohort B')           % COR    
title('Legend Specified Correctly') 
print('-r900', '-dtiff', 'consecLegHan_COR') 

% legend('cohort A','cohort B')                 % INCOR     
% title('Legend Specified Incorrectly') 
% print('-r900', '-dtiff', 'consecLegHan_INCOR') 

end


function p = modelparams(ns)
%MODELPARAMS Specification of model parameters.
%   P = MODELPARAMS(NS) creates a structure |P| storing the model 
%   parameters for |NS| subjects.
 
% Reset the random number generator to the default
rng default
p.numSub = ns;                  % number of subjects
% specify model parameters for all subjects
p.ka = 1 + rand(ns,1);          % absorption rates 
p.V = 15 + rand(ns,1)*2;        % volume of distribution 
p.F = abs(1 - rand(ns,1)*0.5);  % bioavailability 
p.CL = 5 + rand(ns,1);          % clearance

end


function dydt = derivatives(~, y, p)
%DERIVATIVES Compute the right-hand side of the ODE.
%   DYDT = DERIVATIVES(T,Y,P) calculates |DYDT|, the right-hand side
%   of the ODE model, at points defined by the vector of dependent
%   variable |Y|, time |T|, and with parameters |P|.
%
%   See also ode15s

% set dependent variables (for one subject)
a = y(1);    % drug amount                                
c = y(2);    % concentration                                  
% PK Model
dadt = -p.ka*a;
dcdt = (p.ka/p.V/p.F*a - p.CL/p.V*c);
% Derivatives vector of ODE system
dydt = [ dadt        
         dcdt ];  
end



