function explore()
%EXPLORE conduct exploratory data analysis
%   FUNCTION EXPLORE() reads raw data from a population and creates
%   graphs for exploratory data analysis  

close all;
clear; clc;
nmData = load('nmData');

id   = nmData.Data(:,1);
time = nmData.Data(:,2);
conc = nmData.Data(:,3);
wt   = nmData.Data(:,4);
sex  = nmData.Data(:,5);
[id time conc wt sex]           %#ok<NOPRT>     % show data
unique(id)'                     %#ok<NOPRT>     % show subjects

% individual profiles
fig1 = figure;
for i = 1:20;           %length(unique(id));
    subplot(4,5,i)
    idx = id == i; 
    sexi = sex(idx);
    if sexi == 1
        psb = '-ro';
    else
        psb = '-b*';
    end
    semilogy(time(idx),conc(idx),psb)
    axis([0 4 10^-5 10^5])
    title(['ID=',num2str(i)])
end
[~,hx]=suplabel('Time');                      set(hx,'FontSize',14)
[~,hy]=suplabel('Drug Concentration','y');    set(hy,'FontSize',14)
[~,ht]=suplabel(['Individual Observations',10,10],'t'); 
set(ht,'FontSize',16)
print(fig1, '-r900', '-dtiff', 'explore1');

fig2 = figure; 
for i = 1:length(unique(id));
    idx = id == i; 
    sexi = sex(idx);
    if sexi == 1
        psb = '-ro';
    else
        psb = '-b*';
    end
    ax(i) = subplot(1,2,sexi+1);    %#ok<AGROW>
    semilogy(time(idx),conc(idx),psb)
    axis([0 4 10^-5 10^5])
    title(['SEX=',num2str(sexi(1))],'FontSize',15)
    xlabel('Time','FontSize',15)
    hold on
end
set(ax(1),'FontSize',14); set(ax(2),'FontSize',15)
print(fig2, '-r900', '-dtiff', 'explore2');

maxc = grpstats([conc sex],id,@max);
wt  = grpstats(wt,id,@max);
fig3 = figure; set(axes, 'FontSize', 15)
plot(wt(maxc(:,2)==0)+50,maxc(maxc(:,2)==0),'*b','MarkerSize',7)
hold on
plot(wt(maxc(:,2)==1)+50,maxc(maxc(:,2)==1),'or','MarkerSize',7)
xlabel('Body Weight [kg]')
ylabel('Cmax [\mug/L]')
legend('male','female')
print(fig3, '-r900', '-dtiff', 'explore3');

end


