function indProfilesMod
%INDPROFILESMOD Simulate time profiles and demonstrate 'super labels'
%
%   This function uses suplabel from MATLAB Central:
%   http://www.mathworks.ch/matlabcentral/fileexchange/7772-suplabel
%   Copyright (c) 2004, Ben Barrowes
%   All rights reserved.
%   Code covered by the BSD License: http://www.mathworks.com/
%   matlabcentral/fileexchange/view_license?file_info_id=7772


ns = 20;
p = modelparams(ns); 
a0 = 10*ones(1,1); c0 = zeros(1,1); y0 = [a0; c0]; tspan = [0 15];
for id = 1:p.numSub 
    pind = struct('ka',p.ka(id), ... 
                  'V',p.V(id),   ...
                  'F',p.F(id),   ... 
                  'CL',p.CL(id));
    [t,y] = ode15s(@derivatives, tspan, y0, [], pind);
    subplot(5,4,id)
    plot(t,y(:,2),'Color','k' )
    title(['ID=',num2str(id)]);
end
[~,hx]=suplabel('Time');                   set(hx,'FontSize',14)
[~,hy]=suplabel('Drug Concentration','y'); set(hy,'FontSize',14)
[~,ht]=suplabel(['Time Courses', 10],'t'); set(ht,'FontSize',18)
print('-r900', '-dtiff', 'indProfilesMod')

end


function p = modelparams(ns)
%MODELPARAMS Specification of model parameters.
%   P = MODELPARAMS(NS) creates a structure |P| storing the model 
%   parameters for |NS| subjects.
 
% Reset the random number generator to the default
rng default
p.numSub = ns;                  % number of subjects
% specify model parameters for all subjects
p.ka = 1 + rand(ns,1);          % absorption rates 
p.V = 15 + rand(ns,1)*2;        % volume of distribution 
p.F = abs(1 - rand(ns,1)*0.5);  % bioavailability 
p.CL = 5 + rand(ns,1);          % clearance

end


function dydt = derivatives(~, y, p)
%DERIVATIVES Compute the right-hand side of the ODE.
%   DYDT = DERIVATIVES(T,Y,P) calculates |DYDT|, the right-hand side
%   of the ODE model, at points defined by the vector of dependent
%   variable |Y|, time |T|, and with parameters |P|, specified for
%   one subject.
%
%   See also ode15s

% set dependent variables for all subjects at ones (vectorization)
a = y(1);    % drug amount                                
c = y(2);    % concentration                                  
% PK Model
dadt = -p.ka*a;
dcdt = (p.ka/p.V/p.F*a - p.CL/p.V*c);
% Derivatives vector of ODE system
dydt = [ dadt        
         dcdt ];
end



