function c = lapl1com()
%LAPL1COM Laplace solution for one-compartment model with infusion.
%   C = LAPL1COM() solves the equation dcdt = r/V - k*c using
%   first Laplace transform and then inverse Laplace transform. 
%   The result is a function |C| = f(t) in analytic form.

syms R CL V  s t k dcdt  Lc c r Lr

% differential equation in analytic form (symbols)
dcdt = sym('diff(c(t),t)');
c = sym('c(t)');
r = sym('r(t)');
equation = dcdt - r/V + CL/V*c;
transformL = laplace(equation, t, s);
% simplify the Laplace form of the equation
transformL = subs(transformL, {'c(0)', 'laplace(c(t), t, s)', ...
    'laplace(r(t), t, s)'}, {0 , Lc, Lr});    %#ok<NODEF> 
transformL = collect(collect(transformL, V), Lc);
% solution as Laplace transform Lc(s) 
Lc = solve(transformL,Lc);
Ks = Lc/Lr;     % transform function 
pretty(Ks)
% specify the input (dosing)
r = R*(heaviside(t) - heaviside(t-2));  % infusion
%r = R*dirac(t);                        % bolus
Us = laplace(r, t, s);
Ys = Ks*Us;
c = ilaplace(Ys, s, t);
pretty(c)
display(['c(t) = ' char(c)]);

end
