function c = lapl1combolus()
%LAPL1COMBOLUS Laplace solution for one-compartment model with bolus.
%   C = LAPL1COMBOLUS() solves the equation dcdt = r/V - k*c using
%   first Laplace transform and then inverse Laplace transform. 
%   The result is a function |c| = f(t) in analytical form

% declare symbolic variables
syms D CL V s t k dcdt Lc c r Lr
% differential equation in analytic form (symbols)
dcdt = sym('diff(c(t),t)');
c = sym('c(t)');
r = sym('r(t)');
equation = dcdt - r/V + CL/V*c;
transformL = laplace(equation, t, s);
% simplify the Laplace form of the equation
transformL = subs(transformL, {'c(0)', 'laplace(c(t), t, s)', ...
    'laplace(r(t), t, s)'}, {0 , Lc, Lr});  %#ok<NODEF> 
transformL = collect(collect(transformL, V), Lc);
% solution as Laplace transform Lc(s) 
Lc = solve(transformL,Lc);
Ks = Lc/Lr;     % transform function 
% specify the input (dosing)
% r = R*(heaviside(t) - heaviside(t-2));  % valid for infusion
r = D*dirac(t);                           % valid for bolus
Us = laplace(r, t, s);
Ys = Ks*Us;
c = ilaplace(Ys, s, t);
display(['c(t) = ' char(c)]);
pretty(c);

end


