function pbpk1
%PBPK1 Solve a basic PBPK model, representing blood and 1 organ.
%   PBPK1 calculates the time courses of the drug concentration
%   in blood and in 1 organ considered in a PKPB model, and produces
%   the respective graphs.

p.Q = 2;
p.V = 5;
p.R = 1;
p.Vb = 10;
p.C = 0;
p.Cb = 10;

timeEnd = 12;
[t, y]=ode45(@derivatives,[0 timeEnd],[p.Cb; p.C],[],p);
plot(t,y,'LineWidth',2)
hold on
p.R = 2;
[t, y]=ode45(@derivatives,[0 timeEnd],[p.Cb; p.C],[],p);
plot(t,y,'LineWidth',2)

xlabel('Time [h]');
ylabel('Drug Concentrations [mg/L]');
legend('Blood','Organ','Location','South')
text(10,7.2,'R_{Organ} = 1')
text(10,9.2,'R_{Organ} = 2')
text(10,4.2,'R_{Organ} = 2')
print('-dtiff','-r900','pbpk1.tif')

end     


function dydt = derivatives(~, y, p)
%DERIVATIVES Compute the right-hand side of the ODE.
%   DYDT = DERIVATIVES(T, Y, P) calculates |DYDT|, the right-hand
%   side of the ODE model, at points defined by the vector of
%   dependent variables |Y|, time |T|, and with parameters |P|.

Cb = y(1);
C  = y(2);
Ca = Cb;
Cv = C/p.R;
dydt(1) = p.Q*(Cv - Ca)/p.Vb;
dydt(2) = p.Q*(Ca - Cv)/p.V;
dydt = [dydt(1); dydt(2)];

end
