function simuLegHan
%SIMULEGHAN Simulate 2 cohorts and demonstrate creation of legend

ns = 10;
p = modelparams(ns); 

%cohort A
a0 = 100*ones(ns,1); c0 = zeros(ns,1); y0 = [a0; c0]; tspan = [0 15];
[t,y] = ode15s(@derivatives, tspan, y0, [], p);
hA = plot(t,y(:,ns+1 : 2*ns), 'Color', 'b', 'LineWidth',2); hold on
% AAA

%cohort B
a0 = 200*ones(ns,1); c0 = zeros(ns,1); y0 = [a0; c0]; tspan = [0 15];
[t,y] = ode15s(@derivatives, tspan, y0, [], p);
hB = plot(t,y(:,ns+1 : 2*ns), 'Color', 'r', 'LineWidth',2); hold on
% BBB

xlabel('Time'); ylabel('Concentration'); title(' Legend Demo')
% Setup a legend
legend([hA(1) hB(1)],'cohort A','cohort B') % LEG 1 
  
print('-r900', '-dtiff', 'simuLegHan') 

end



function p = modelparams(ns)
%MODELPARAMS Specification of model parameters.
%   P = MODELPARAMS(NS) creates a structure |P| storing the model 
%   parameters for |NS| subjects.
 
% Reset the random number generator to the default
rng default
p.numSub = ns;                  % number of subjects
% specify model parameters for all subjects
p.ka = 1 + rand(ns,1);          % absorption rates 
p.V = 15 + rand(ns,1)*2;        % volume of distribution 
p.F = abs(1 - rand(ns,1)*0.5);  % bioavailability 
p.CL = 5 + rand(ns,1);          % clearance

end


function dydt = derivatives(~, y, p)
%DERIVATIVES Compute the right-hand side of the ODE.
%   DYDT = DERIVATIVES(T,Y,P) calculates |DYDT|, the right-hand side
%   of the ODE model, at points defined by the vector of dependent
%   variable |Y|, time |T|, and with parameters |P|.
%
%   See also ode15s

ns = p.numSub;          % number of subjects
% set dependent variables for all subjects at ones (vectorization)
a = y(   1 :   ns);     % drug amount                                
c = y(ns+1 : 2*ns);     % concentration                                  
% PK Model for all subjects
dadt = -p.ka.*a;
dcdt = (p.ka./p.V./p.F.*a - p.CL./p.V.*c); 
% Derivatives vector of ODE system
dydt = [ dadt        
         dcdt ];  
end


