function units
%UNITS Evaluate units in the HH model.
%   UNITS checks the general correctness of units in the HH model, 
%   given the model parameters in 'standard units'. The procedure
%   compares the output unit on the left side with components of the
%   right one.

syms F S cm mA mV ohm s uF uA
% basic units
OMEGA = mV/mA;              % ohm
S = 1/ohm;                  % siemens
mS = S/1000;                % milisiemens
F = mA/mV*s;                % farad
uF = F/1000000;             % microfarad
ms = s/1000;                % milisecond
% Put standard units and compare both sides of the HH model equation
SL = cm/(OMEGA*cm)*mV/cm^2; % Left side of HH 
SRC  = uF/cm^2*mV/ms;       % right side of HH: ref. to capacitor 
SRK  = mS/cm^2*mV;          % right side of HH: ref. to K  channel
SRNa = mS/cm^2*mV;          % right side of HH: ref. to Na channel
SRL  = mS/cm^2*mV;          % right side of HH: ref. to L  channel
display(['SL   = ', char(simplify(SL))])
display(['SRC  = ', char(simplify(SRC))])
display(['SRK  = ', char(simplify(SRK))])
display(['SRNa = ', char(simplify(SRNa))])
display(['SRL  = ', char(simplify(SRL))])

end

